/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Copyright (C) 2003-2006 Imendio AB
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GOSSIP_SOUND_H__
#define __GOSSIP_SOUND_H__

#include <libgossip/gossip-session.h>

typedef enum {
	GOSSIP_SOUND_CHAT,
	GOSSIP_SOUND_OFFLINE,
	GOSSIP_SOUND_ONLINE
} GossipSound;

void gossip_sound_init        (GossipSession *session);
void gossip_sound_finalize    (void);
void gossip_sound_play        (GossipSound sound);
void gossip_sound_set_enabled (gboolean    enabled);

#endif /* __GOSSIP_SOUND_H__ */
